import json
import requests


# POST MessageSend
def send_by_mobile_number(Messages='', MobileNumbers='', LineNumber='', SendDateTime='', Token=''):
    url = "http://RestfulSms.com/api/MessageSend"
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Messages": [Messages],
        "MobileNumbers": [MobileNumbers],
        "LineNumber": LineNumber,
        "SendDateTime": SendDateTime,
        "CanContinueInCaseOfError": "false",
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)
    return response


# GET SMSLine
def get_sms_line(Token=''):
    url = "http://RestfulSms.com/api/SMSLine"
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)
    return response


# GET MessageSend (ReportByDate)
def get_report_by_date(StartDate_SHAMSI='', EndDate_SHAMSI='', RowsPerPage=10, RequestedPageNumber=1, Token=''):
    url = f'http://RestfulSms.com/api/MessageSend?Shamsi_FromDate={StartDate_SHAMSI}&Shamsi_ToDate={EndDate_SHAMSI}&RowsPerPage={RowsPerPage}&RequestedPageNumber={RequestedPageNumber}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)
    return response


# GET MessageSend (ReportById)
def get_report_by_id(self, sms_id, Token=''):
    url = f'http://RestfulSms.com/api/MessageSend?id={sms_id}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)
    return response


# GET MessageSend (ReportByBatchKey)
def get_report_by_BatchKey(self, PageID='', BatchKey='', Token=''):
    url = f'http://RestfulSms.com/api/MessageSend?pageId={PageID}&batchKey={BatchKey}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)
    return response


# GET ReceiveMessage (ByLastID)
def get_receive_message_by_last_id(ByLastID='', Token=''):
    url = f'http://RestfulSms.com/api/ReceiveMessage?id={ByLastID}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)
    return response


# GET ReceiveMessage (ByDate)
def get_receive_message_by_date(StartDate_SHAMSI='', EndDate_SHAMSI='', RowsPerPage='10',
                                RequestedPageNumber='1', Token=''):
    url = f'http://RestfulSms.com/api/ReceiveMessage?Shamsi_FromDate={StartDate_SHAMSI}&Shamsi_ToDate={EndDate_SHAMSI}&RowsPerPage={RowsPerPage}&RequestedPageNumber={RequestedPageNumber}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)
    return response


# POST VerificationCode
def VerificationCode(Code='', MobileNumber='', Token=''):
    url = 'http://RestfulSms.com/api/VerificationCode'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Code": Code,
        "MobileNumber": MobileNumber
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response


# POST UltraFastSend
def UltraFastSend(ParameterArray='', Mobile='', TemplateId='', Token=''):
    url = 'http://RestfulSms.com/api/UltraFastSend'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "ParameterArray": ParameterArray,
        "Mobile": Mobile,
        "TemplateId": TemplateId
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response


# POST MessageReport
def MessageReport(ReportType='1', SentReturnId='null', FromDate='', ToDate='', Token=''):
    url = 'https://RestfulSms.com/api/MessageReport'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "ReportType": ReportType,
        "SentReturnId": SentReturnId,
        "FromDate": FromDate,
        "ToDate": ToDate
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response



import requests
import json


# POST CustomerClubContact (AddContact)
def add_contact(Prefix='', FirstName='', LastName='', Mobile='', BirthDay='', CategoryId='', Token=''):
    url = "http://restfulsms.com/api/CustomerClubContact"
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Prefix": Prefix,
        "FirstName": FirstName,
        "LastName": LastName,
        "Mobile": Mobile,
        "BirthDay": BirthDay,
        "CategoryId": CategoryId
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response


# PUT CustomerClubContact (UpdateContact)
def update_contact(Prefix='', FirstName='', LastName='', Mobile='', BirthDay='', CategoryId='', Token=''):
    url = 'http://restfulsms.com/api/CustomerClubContact'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Prefix": Prefix,
        "FirstName": FirstName,
        "LastName": LastName,
        "Mobile": Mobile,
        "BirthDay": BirthDay,
        "CategoryId": CategoryId
    }
    response = requests.put(url, data=json.dumps(body),
                            headers=headers)

    return response


# GET CustomerClubContact (GetCategories)
def get_categories(self, Token=''):
    url = 'http://restfulsms.com/api/CustomerClubContact/GetCategories'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)

    return response


# GET CustomerClubContact (GetContactsByCategory&ById)
def get_contacts_by_categoryId(categoryId='', pageNumber='', Token=''):
    url = f'http://restfulsms.com/api/CustomerClubContact/GetContactsByCategoryById?categoryId={categoryId}&pageNumber={pageNumber}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)

    return response


# GET CustomerClubContact (GetAllContactsByPageID)
def get_allcontacts_By_pageid(pageNumber='', Token=''):
    url = f'http://restfulsms.com/api/CustomerClubContact/GetContacts?pageNumber={pageNumber}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)

    return response


# POST CustomerClub (Send)
def send_customer_club(Messages='', MobileNumbers='',
                       SendDateTime='', CanContinueInCaseOfError="true", Token=''):
    url = 'http://RestfulSms.com/api/CustomerClub/Send'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Messages": Messages,
        "MobileNumbers": MobileNumbers,
        "SendDateTime": SendDateTime,
        "CanContinueInCaseOfError": CanContinueInCaseOfError
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response


# POST CustomerClub (AddContact&Send)

def add_Contact_send(Prefix='', FirstName='', LastName='', Mobile='', BirthDay='', CategoryId='',
                     MessageText='', Token=''):
    url = 'http://RestfulSms.com/api/CustomerClub/AddContactAndSend'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Prefix": Prefix,
        "FirstName": FirstName,
        "LastName": LastName,
        "Mobile": Mobile,
        "BirthDay": BirthDay,
        "CategoryId": CategoryId,
        "MessageText": MessageText
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response


# POST CustomerClub (SendToCategories)

def Send_To_categories(self, Messages='', contactsCustomerClubCategoryIds='', SendDateTime='',
                       CanContinueInCaseOfError='false', Token=''):
    url = 'http://RestfulSms.com/api/CustomerClub/SendToCategories'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Messages": Messages,
        "contactsCustomerClubCategoryIds": contactsCustomerClubCategoryIds,
        "SendDateTime": SendDateTime,
        "CanContinueInCaseOfError": CanContinueInCaseOfError
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response


# GET CustomerClub (GetSendMessagesByPagination)

def get_send_messages_by_pagination(pageIndex=1, rowCount=10, Token=''):
    url = f'http://restfulsms.com/api/CustomerClub/GetSendMessagesByPagination?pageIndex={pageIndex}&rowCount={rowCount}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)

    return response


# GET CustomerClub (GetSendMessagesByPaginationAndLastId)

def get_send_messages_by_pagination_And_lastId(lastId='', Token=''):
    url = f'http://restfulsms.com/api/CustomerClub/GetSendMessagesByPaginationAndLastId?lastId={lastId}'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    response = requests.get(url, headers=headers)

    return response


# POST CustomerClub (DeleteContactCustomerClub)

def delete_contact_customerClub(Mobile='', CanContinueInCaseOfError='false', Token=''):
    url = 'http://restfulsms.com/api/CustomerClub/DeleteContactCustomerClub'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': Token
    }
    body = {
        "Mobile": Mobile,
        "CanContinueInCaseOfError": CanContinueInCaseOfError
    }
    response = requests.post(url, data=json.dumps(body),
                             headers=headers)

    return response



import requests
import json


def get_token(UserApiKey='', SecretKey=''):
    url = 'http://RestfulSms.com/api/Token'
    headers = {
        "Content-Type": "application/json",
    }
    body = {
        "UserApiKey": UserApiKey,
        "SecretKey": SecretKey
    }
    response = requests.post(url, data=json.dumps(body), headers=headers)
    if response.status_code is 201:
        if response.json()['IsSuccessful'] is True:
            secure_token = response.json()['TokenKey']
            return secure_token
    return None


def get_credit(token=''):
    url = 'http://RestfulSms.com/api/credit'
    headers = {
        "Content-Type": "application/json",
        'x-sms-ir-secure-token': token
    }
    response = requests.get(url, headers=headers)
    return response
